hotspot/src/share/vm/runtime/mutexLocker.hpp
changeset 46505 fd4bc78630b1
parent 46384 dacebddcdea0
--- a/hotspot/src/share/vm/runtime/mutexLocker.hpp	Fri May 26 13:47:33 2017 -0700
+++ b/hotspot/src/share/vm/runtime/mutexLocker.hpp	Sat May 27 09:21:01 2017 -0400
@@ -38,7 +38,7 @@
 extern Mutex*   VMStatistic_lock;                // a lock used to guard statistics count increment
 extern Mutex*   JNIGlobalHandle_lock;            // a lock on creating JNI global handles
 extern Mutex*   JNIHandleBlockFreeList_lock;     // a lock on the JNI handle block free list
-extern Mutex*   MemberNameTable_lock;            // a lock on the MemberNameTable updates
+extern Mutex*   ResolvedMethodTable_lock;        // a lock on the ResolvedMethodTable updates
 extern Mutex*   JmethodIdCreation_lock;          // a lock on creating JNI method identifiers
 extern Mutex*   JfieldIdCreation_lock;           // a lock on creating JNI static field identifiers
 extern Monitor* JNICritical_lock;                // a lock used while entering and exiting JNI critical regions, allows GC to sometimes get in